Author: Elmar Pruesse <elmar@pruesse.net>
Last-Update: Tue, 02 Sep 2014 17:56:47 +0200
Description: fix lintian detected spelling errors
Origin: upstream, http://bugs.arb-home.de/changeset/12815

--- a/GDE/CLUSTALW/interface.c
+++ b/GDE/CLUSTALW/interface.c
@@ -1372,7 +1372,7 @@ void parse_params(Boolean xmenus)
 
 
 /*****************************************************************************/
-/*  Check to see if sequence type is explicitely stated..override ************/
+/*  Check to see if sequence type is explicitly stated..override ************/
 /* the automatic checking (DNA or Protein).   /type=d or /type=p *************/
 /*****************************************************************************/
 	if(settype != -1)
--- a/ARBDB/adGene.cxx
+++ b/ARBDB/adGene.cxx
@@ -251,7 +251,7 @@ GEN_position *GEN_read_position(GBDATA *
 
     if (gb_pos_joined) {
         parts = GB_read_int(gb_pos_joined);
-        if (parts != 1) { // splitted
+        if (parts != 1) { // split
             if (parts>1) joinable = true;
             else if (parts<-1) parts = -parts; // neg value means "not joinable" (comes from feature location 'order(...)')
             else error = GBS_global_string("Illegal value %i in 'pos_joined'", parts);
--- a/ARBDB/adsocket.cxx
+++ b/ARBDB/adsocket.cxx
@@ -1356,7 +1356,7 @@ void GB_remove_on_exit(const char *filen
 
 void GB_split_full_path(const char *fullpath, char **res_dir, char **res_fullname, char **res_name_only, char **res_suffix) {
     // Takes a file (or directory) name and splits it into "path/name.suffix".
-    // If result pointers (res_*) are non-NULL, they are assigned heap-copies of the splitted parts.
+    // If result pointers (res_*) are non-NULL, they are assigned heap-copies of the split parts.
     // If parts are not valid (e.g. cause 'fullpath' doesn't have a .suffix) the corresponding result pointer
     // is set to NULL.
     //
--- a/NTREE/NT_tree_cmp.cxx
+++ b/NTREE/NT_tree_cmp.cxx
@@ -145,7 +145,7 @@ AWT_species_set::~AWT_species_set() {
 
 AWT_species_set *AWT_species_set_root::move_tree_2_ssr(AP_tree *node) {
     AWT_species_set *ss;
-    // Warning: confusing ressource handling:
+    // Warning: confusing resource handling:
     // - leafs are returned "NOT owned by anybody"
     // - inner nodes are added to and owned by this->sets
 
--- a/GENOM/GEN_gene.cxx
+++ b/GENOM/GEN_gene.cxx
@@ -37,7 +37,7 @@
 //
 // pos_complement        = 1 -> CDS is on opposite strand
 
-// fields for splitted genes:
+// fields for split genes:
 // --------------------------
 // pos_joined         = xxx -> gene consists of abs(xxx) parts (if missing xxx == 1 is assumed)
 //
@@ -83,7 +83,7 @@
 // pos_uncertain = contains 2 chars (1. for start-pos, 2. for end-pos); = means 'pos is exact'; < means 'pos may be lower'; > means 'pos may be higher'; missing -> like ==
 // complement    = 1 -> encoding from right to left
 //
-// fields for splitted genes:
+// fields for split genes:
 // --------------------------
 // pos_joined               = xxx -> gene consists of xxx parts (may not exist if xxx == 1)
 // pos_beginxxx, pos_endxxx = start-/end-positions for parts 2...n
@@ -138,7 +138,7 @@ GEN_gene::GEN_gene(GBDATA *gb_gene_, GEN
 }
 
 GEN_gene::GEN_gene(GBDATA *gb_gene_, GEN_root *root_, const GEN_position *location, int partNumber) {
-    //  partNumber 1..n which part of a splitted gene
+    //  partNumber 1..n which part of a split gene
     //  maxParts   1..n of how many parts consists this gene?
 
     init(gb_gene_, root_);
--- a/PRIMER_DESIGN/primer_design.cxx
+++ b/PRIMER_DESIGN/primer_design.cxx
@@ -347,7 +347,7 @@ static void primer_design_event_init(AW_
                 length     = gene_length;
                 add_offset = genPos->start_pos[0];
 #if defined(WARN_TODO)
-#warning does this work with splitted genes ?
+#warning does this work with split genes ?
 #warning warn about uncertainties ?
 #endif
             }
--- a/CORE/arb_strarray.cxx
+++ b/CORE/arb_strarray.cxx
@@ -36,7 +36,7 @@ void CharPtrArray::sort(CharPtrArray_com
 void GBT_splitNdestroy_string(ConstStrArray& names, char*& namelist, const char *separator, bool dropEmptyTokens) {
     /*! Split 'namelist' into an array of substrings at each member of 'separator'.
      *
-     * @param names pointers to splitted parts (into namelist)
+     * @param names pointers to split parts (into namelist)
      * @param namelist string containing separator delimited parts
      * @param separator contains all characters handled as separators
      * @param dropEmptyTokens if true, empty tokens will be skipped
--- a/CORE/arb_progress.h
+++ b/CORE/arb_progress.h
@@ -164,7 +164,7 @@ public:
         // 
         // expects to be incremented 'overall_count' times
         //      incrementation is done either
-        //      - explicitely by calling one of the inc...()-functions below or
+        //      - explicitly by calling one of the inc...()-functions below or
         //      - implicitely by creating another arb_progress while this one remains
         //
         // if you can't ahead-determine the exact number of incrementations,
@@ -176,7 +176,7 @@ public:
     explicit arb_progress(const char *title) {
         // open a wrapping progress indicator
         //
-        // expects NOT to be incremented explicitely!
+        // expects NOT to be incremented explicitly!
         //      if arb_progresses are created while this exists, they reuse the progress window.
         //      Useful to avoid spamming the user with numerous popping-up progress windows.
         setup(title, 0);
--- a/WINDOW/AW_xfig.cxx
+++ b/WINDOW/AW_xfig.cxx
@@ -416,7 +416,7 @@ AW_xfig::AW_xfig(const char *filename, i
     free(buffer);
 
     if (error) {
-        error = GBS_global_string("Error: Can't read XFIG ressource - programmers error or defect installation\n"
+        error = GBS_global_string("Error: Can't read XFIG resource - programmers error or defect installation\n"
                                   "Reason: %s\n", error);
 
         if (font_width>0 && font_height>0) { // react with fatal exit
--- a/ARB_GDE/GDE_event.cxx
+++ b/ARB_GDE/GDE_event.cxx
@@ -130,7 +130,7 @@ static char *ReplaceArgs(AW_root *awr, c
                 }
                 else {
                     aw_message(GBS_global_string("[ARB_GDE]: Cannot access label of '%s'\n", symbol));
-                    return NULL; // @@@ ignores ressources (should only occur during development)
+                    return NULL; // @@@ ignores resources (should only occur during development)
                 }
             }
 
--- a/TOOLS/arb_consensus_tree.cxx
+++ b/TOOLS/arb_consensus_tree.cxx
@@ -169,7 +169,7 @@ int ARB_main(int argc, char *argv[]) {
                     error = save_tree_as_newick(cons_tree, savename, comment);
                 }
                 else {
-                    printf("sucessfully created consensus tree\n"
+                    printf("successfully created consensus tree\n"
                            "(no savename specified -> tree not saved)\n");
                 }
                 delete cons_tree;
--- a/TOOLS/arb_gene_probe.cxx
+++ b/TOOLS/arb_gene_probe.cxx
@@ -31,7 +31,7 @@ using namespace std;
 // --------------------------------------------------------------------------------
 
 static int gene_counter          = 0; // pre-incremented counters
-static int splitted_gene_counter = 0;
+static int split_gene_counter = 0;
 static int intergene_counter     = 0;
 
 struct nameOrder {
@@ -299,7 +299,7 @@ static GB_ERROR create_gene(GBDATA *gb_s
     return "Illegal gene positions (start behind end)";
 }
 
-static GB_ERROR create_splitted_gene(GBDATA *gb_species_data2, PositionPairList& part_list, const char *ali_genome, const char *long_gene_name) {
+static GB_ERROR create_split_gene(GBDATA *gb_species_data2, PositionPairList& part_list, const char *ali_genome, const char *long_gene_name) {
     GB_ERROR                     error    = 0;
     PositionPairList::iterator list_end = part_list.end();
 
@@ -339,7 +339,7 @@ static GB_ERROR create_splitted_gene(GBD
     }
 
     char internal_name[128];
-    sprintf(internal_name, "s%x", splitted_gene_counter++);
+    sprintf(internal_name, "s%x", split_gene_counter++);
 
     const PositionPair&  first_part  = part_list.front();
     GBDATA              *gb_species2 = create_gene_species(gb_species_data2, internal_name, long_gene_name, first_part.begin,
@@ -348,7 +348,7 @@ static GB_ERROR create_splitted_gene(GBD
     if (!gb_species2) error = GB_await_error();
     else {
 #if defined(DEBUG) && 0
-        printf("splitted gene: long_gene_name='%s' internal_name='%s' split_pos_list='%s'\n",
+        printf("split gene: long_gene_name='%s' internal_name='%s' split_pos_list='%s'\n",
                long_gene_name, internal_name, split_pos_list);
 #endif // DEBUG
         error = GBT_write_string(gb_species2, "splitpos", split_pos_list);
@@ -386,7 +386,7 @@ static GB_ERROR insert_genes_of_organism
     GenePositionMap geneRanges;
 
     int gene_counter_old          = gene_counter; // used for statistics only (see end of function)
-    int splitted_gene_counter_old = splitted_gene_counter;
+    int split_gene_counter_old = split_gene_counter;
     int intergene_counter_old     = intergene_counter;
 
     GBDATA *gb_ali_genom = GBT_read_sequence(gb_organism, GENOM_ALIGNMENT);
@@ -417,8 +417,8 @@ static GB_ERROR insert_genes_of_organism
                     error = create_gene(gb_species_data2, first_part.begin, first_part.end, ali_genom, long_gene_name);
                     geneRanges.announceGene(first_part);
                 }
-                else {          // splitted gene
-                    error = create_splitted_gene(gb_species_data2, part_list, ali_genom, long_gene_name);
+                else {          // split gene
+                    error = create_split_gene(gb_species_data2, part_list, ali_genom, long_gene_name);
 
                     for (PositionPairList::iterator p = part_list.begin(); p != part_list.end(); ++p) {
                         geneRanges.announceGene(*p);
@@ -447,8 +447,8 @@ static GB_ERROR insert_genes_of_organism
     if (error && organism_name) error = GBS_global_string("in organism '%s': %s", organism_name, error);
 
     {
-        int new_genes          = gene_counter-gene_counter_old; // only non-splitted genes
-        int new_splitted_genes = splitted_gene_counter-splitted_gene_counter_old;
+        int new_genes          = gene_counter-gene_counter_old; // only non-split genes
+        int new_split_genes = split_gene_counter-split_gene_counter_old;
         int new_intergenes     = intergene_counter-intergene_counter_old;
 
         unsigned long genesSize    = geneRanges.getAllGeneSize();
@@ -456,10 +456,10 @@ static GB_ERROR insert_genes_of_organism
         double        data_grow    = overlaps/double(PositionPair::genome_length)*100;
         double        gene_overlap = overlaps/double(genesSize)*100;
 
-        if (new_splitted_genes) {
+        if (new_split_genes) {
 
-            printf("  - %s: %i genes (%i splitted), %i intergenes",
-                   organism_name, new_genes+new_splitted_genes, new_splitted_genes, new_intergenes);
+            printf("  - %s: %i genes (%i split), %i intergenes",
+                   organism_name, new_genes+new_split_genes, new_split_genes, new_intergenes);
         }
         else {
             printf("  - %s: %i genes, %i intergenes",
@@ -536,8 +536,8 @@ int ARB_main(int argc, char *argv[]) {
 
         if (!error) {
             printf("%i species had data in alignment '" GENOM_ALIGNMENT "'.\n"
-                   "Found %i genes (%i were splitted) and %i intergene regions.\n",
-                   ali_genom_species, gene_counter, splitted_gene_counter, intergene_counter);
+                   "Found %i genes (%i were split) and %i intergene regions.\n",
+                   ali_genom_species, gene_counter, split_gene_counter, intergene_counter);
         }
 
         if (!error) {
--- a/STAT/st_quality.hxx
+++ b/STAT/st_quality.hxx
@@ -64,7 +64,7 @@ public:
 };
 
 class LikelihoodRanges : virtual Noncopyable {
-    /*! The alignment is splitted into multiple, similar-sized column ranges.
+    /*! The alignment is split into multiple, similar-sized column ranges.
      * For each range the likelihoods get summarized
      */
     size_t           ranges;
--- a/SL/FAST_ALIGNER/fast_aligner.cxx
+++ b/SL/FAST_ALIGNER/fast_aligner.cxx
@@ -67,7 +67,7 @@ enum FA_turn {
 };
 
 enum FA_reference {
-    FA_REF_EXPLICIT,            // reference sequence explicitely specified
+    FA_REF_EXPLICIT,            // reference sequence explicitly specified
     FA_REF_CONSENSUS,           // use group consensus as reference
     FA_REF_RELATIVES,           // search next relatives by PT server
 };

--- a/GDE/CLUSTAL/amenu.c
+++ b/GDE/CLUSTAL/amenu.c
@@ -342,7 +342,7 @@ void parse_params()
 
 
 /*****************************************************************************/
 /*  Check to see if sequence type is explicitely stated..override ************/
 /* the automatic checking (DNA or Protein).   /type=d or /type=p *************/
 /*****************************************************************************/
 	if(check_param(params, typest, param_arg, &param_arg_len)) 
@@ -351,11 +351,11 @@ void parse_params()
 				dnaflag = FALSE;
 				explicit_dnaflag = TRUE;
 				fprintf(stdout,
-				"\nSequence type explicitely set to Protein\n");
+				"\nSequence type explicitly set to Protein\n");
 			}
 			else if(param_arg[0] == 'd') {
 				fprintf(stdout,
-				"\nSequence type explicitely set to DNA\n");
+				"\nSequence type explicitly set to DNA\n");
 				dnaflag = TRUE;
 				explicit_dnaflag = TRUE;
 			}
@@ -342,7 +342,7 @@ void parse_params()
 
 /*****************************************************************************/
-/*  Check to see if sequence type is explicitely stated..override ************/
+/*  Check to see if sequence type is explicitly stated..override ************/
 /* the automatic checking (DNA or Protein).   /type=d or /type=p *************/
 /*****************************************************************************/